@@ -1,4 +1,5 @@
 from ddd_objects.domain.value_obj import ExpiredValueObject
+from ddd_objects.domain.exception import ParameterError
 
 class Number(ExpiredValueObject):
     def __init__(self, value):
@@ -16,6 +17,23 @@ class Status(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class IngressHost(ExpiredValueObject):
+    def __init__(self, value):
+        self.parts = value.split('.')
+        if len(self.parts)>3 or len(self.parts)==1:
+            raise ParameterError('Invaild value')
+        super().__init__(value, None)
+    def get_domain_name(self):
+        if len(self.parts)==2:
+            return DomainName(self.value)
+        elif len(self.parts)==3:
+            return DomainName('.'.join(self.parts[-2:]))
+    def get_subdomain(self):
+        if len(self.parts)==2:
+            return Subdomain('@')
+        elif len(self.parts)==3:
+            return Subdomain(self.parts[0])
+
 class SecurityGroupID(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
