@@ -12,14 +12,8 @@ from ddd_objects.lib import Logger, get_md5
 from .ao import K3SController
 from .converter import(
     CommandResultConverter,
-    CommandSettingConverter,
     ConditionConverter,
-    InstanceInfoConverter,
-    InstanceTypeUserSettingConverter,
-    InstanceTypeWithStatusConverter,
-    InstanceUserSettingConverter,
     NodeInfoConverter,
-    OSSOperationInfoConverter
 )
 from ..domain.entity import(
     CommandResult,
@@ -73,14 +67,8 @@ from .converter import (
 from ..domain.repository import (
     K3SRepository
 )
-instance_info_converter = InstanceInfoConverter()
 condition_converter = ConditionConverter()
-instance_user_setting_converter = InstanceUserSettingConverter()
-oss_operation_info_converter = OSSOperationInfoConverter()
-command_setting_converter = CommandSettingConverter()
 command_result_converter = CommandResultConverter()
-instance_type_status_converter = InstanceTypeWithStatusConverter()
-instance_type_user_converter = InstanceTypeUserSettingConverter()
 node_info_converter = NodeInfoConverter()
 config_map_user_setting_converter = ConfigMapUserSettingConverter()
 node_user_setting_converter = NodeUserSettingConverter()
